@@ -23,8 +23,7 @@ class Facade(object):
         self.currency = settings.DATACASH_CURRENCY
 
     def handle_response(self, method, order_number, amount, response):
-        with transaction.commit_on_success():
-            self.record_txn(method, order_number, amount, response)
+        self.record_txn(method, order_number, amount, response)
         # A response is either successful, declined or an error
         if response.is_successful():
             return response['datacash_reference']
@@ -51,7 +50,12 @@ class Facade(object):
         return 'The transaction was declined by your bank - please check your bankcard details and try again'
 
     def get_friendly_error_message(self, response):
-        return 'An error occurred when communicating with the payment gateway.'
+        # TODO: expand this dict to handle the most common errors
+        errors = {
+            19: 'Unable to fulfill transaction',
+        }
+        default_msg =  'An error occurred when communicating with the payment gateway.'
+        return errors.get(response.status, default_msg)
         
     def generate_merchant_reference(self, order_number):
         return '%s_%s' % (order_number, datetime.datetime.now().microsecond)
